define([], function() { return "import * as React from 'react';\n\nexport interface IImageProps extends React.HTMLProps<HTMLImageElement> {\n  /**\n   * If true, adds the css class 'is-fadeIn' to the image.\n   */\n  shouldFadeIn?: boolean;\n\n  /**\n   * If provided, adds the indicated css class to the image.\n   */\n  className?: string;\n\n  /**\n   * Used to determine how the image is scaled and cropped to fit the frame.\n   *\n   * @default If both dimensions are provided, then the image is fit using ImageFit.scale. Otherwise, the image won't be scaled or cropped.\n   */\n  imageFit?: ImageFit;\n\n  /**\n   * @deprecated\n   * Deprecated at v1.3.6, to be removed at >= v2.0.0.\n   * To replace the src in case of errors, use onLoadingStateChange instead and rerender the Image with a \n   * difference src.\n   */\n  errorSrc?: string;\n\n  /**\n   * If true, the image frame will expand to fill its parent container.\n   */\n  maximizeFrame?: boolean;\n\n  /**\n   * Optional callback method for when the image load state has changed.\n   * The 'loadState' parameter indicates the current state of the Image.\n   */\n  onLoadingStateChange?: (loadState: ImageLoadState) => void;\n}\n\n/**\n * The possible methods that can be used to fit the image.\n */\nexport enum ImageFit {\n  /**\n   * The image is not scaled. The image is centered and cropped within the content box.\n   */\n  center = 0,\n\n  /**\n   * The image is scaled to maintain its aspect ratio while being fully contained within the frame. The image will\n   * be centered horizontally and vertically within the frame. The space in the top and bottom or in the sides of\n   * the frame will be empty depending on the difference in aspect ratio between the image and the frame.\n   */\n  contain = 1,\n\n  /**\n   * The image is scaled to maintain its aspect ratio while filling the frame. Portions of the image will be cropped from\n   * the top and bottom, or from the sides, depending on the difference in aspect ratio between the image and the frame.\n   */\n  cover = 2,\n\n  /**\n   * Neither the image nor the frame are scaled. If their sizes do not match, the image will either be cropped or the\n   * frame will have empty space.\n   */\n  none = 3\n}\n\nexport enum ImageLoadState {\n  /**\n   * The image has not yet been loaded, and there is no error yet.\n   */\n  notLoaded = 0,\n\n  /**\n   * The image has been loaded successfully.\n   */\n  loaded = 1,\n\n  /**\n   * An error has been encountered while loading the image.\n   */\n  error = 2,\n\n  /**\n   * @deprecated\n   * Deprecated at v1.3.6, to be removed at >= v2.0.0.\n   * To replace the src in case of errors, use onLoadingStateChange instead and rerender the Image with a \n   * difference src.\n   */\n  errorLoaded = 3\n}\n"; });